Thanks
======

To anyone who has contributed to this project, thanks for your help!

Attribution
===========
* The URL shortening code, `shorturl.py`, was written by **ksaver**.  See <http://snipplr.com/view/40257/>.  As stated in the file, it's in the Public Domain.
* The HTML-stripping code, `MLStripper.py`, was originally written by **Eloff**.  See <http://stackoverflow.com/questions/753052/strip-html-from-strings-in-python>.
* The filtering of public notes code was originally written by **sazius**.
